/**********************************
All code written by Adam Thole
http://www.adamthole.com
File Last Updated 4/21/2009

This is the main file for Tilt Board v3.0.0 software.
This code is free to use for personal use only.
If you want to use this code for commercial use please contact me: adam@adamthole.com

Please let me know if you find the software useful!
*********************************/

#include <system.h>

#pragma CLOCK_FREQ 8000000
#pragma DATA 0x2007, 0b0001111100010000
#pragma DATA 0x2008, 0x00

//Accelerometer Definitions - Modify to match your accelerometer!
#define VREF 					3000 //Voltage reference for ADC of PIC, in mV
#define ZERO_G 					1500 //Zero G of Accelerometer, in mV
#define SENSITIVITY_PER_G 		300 //Sensitivity per G for accelerometer, in mV

//Input Mode Definitions
#define POTENTIOMETER_XY		0
#define POTENTIOMETER_X			1
#define POTENTIOMETER_Y			2
#define ACCELEROMETER			3
#define EXTERNAL				4

//Used for different XY sensitivity setting calculations
#define SENSITIVITY_SIN_60		((SENSITIVITY_PER_G * 866) / 1000)
#define SENSITIVITY_SIN_45		((SENSITIVITY_PER_G * 707) / 1000)
#define SENSITIVITY_SIN_30		((SENSITIVITY_PER_G * 500) / 1000)

#define MINUS_1G 				(ZERO_G - SENSITIVITY_PER_G)
#define PLUS_1G					(ZERO_G + SENSITIVITY_PER_G)
#define SENSITIVITY_HALF_G		(SENSITIVITY_PER_G / 2)

#define DIGITAL_OUTPUT1_Z		trisa.7 = 1 //Sets "Digital Output 1" as an input, making it a Z (dormant)
#define DIGITAL_OUTPUT1_GND		trisa.7 = 0 //Sets "Digital Output 1" as an output, making it a 0 (active)

#define DIGITAL_OUTPUT2_Z		trisa.6 = 1 //Sets "Digital Output 2" as an input, making it a Z (dormant)
#define DIGITAL_OUTPUT2_GND		trisa.6 = 0 //Sets "Digital Output 2" as an output, making it a 0 (active)

//EEPROM Data
#pragma DATA 0x2100, 120, 120 //totalX, totalY
#pragma DATA 0x2102, ACCELEROMETER, 1 //Use potentiometer by default, Digital_Output_Select = 1(DO1)

unsigned long Write_Data_X, Write_Data_Y, External_Data_X, External_Data_Y;
unsigned long Maximum_G_X, Minimum_G_X, Range_X, Maximum_G_Scaled_X, Minimum_G_Scaled_X, Range_Scaled_X, Scale_Factor_X;
unsigned long Maximum_G_Y, Minimum_G_Y, Range_Y, Maximum_G_Scaled_Y, Minimum_G_Scaled_Y, Range_Scaled_Y, Scale_Factor_Y;
unsigned long Z_AVG = MINUS_1G;
signed int ADC, ADC_X, ADC_Y;
int Total_Degrees_X, Total_Degrees_Y, Input_Mode, Digital_Output_Select;
int data = 0, Z_TTL = 0;

void initialize();
void Load_Settings();
void Calculate_Constants();
void Send_SPI_Data(bool notShutdownX, bool notShutdownY);
void pulse();
void Digital_Outputs();
void Save_EEPROM(int dataToSave);
unsigned long ADC_Read();